<?php

namespace Ebuy\Product\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Ebuy\Product\Repositories\Eloquent\Filters\BrandPublicFilter;
use Ebuy\Product\Repositories\Eloquent\Presenters\BrandListPresenter;
use Ebuy\Product\Interfaces\BrandRepositoryInterface;

class BrandPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(BrandRepositoryInterface $brand)
    {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.product.modules'), 'product', guard_url('product'));
        $this->repository = $brand;

    }

    /**
     * Show brand's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(BrandPublicFilter::class)
            ->setPresenter(BrandListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('product::brand.names'))
            ->view('product::public.brand.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show brand.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('product::brand.name'))
            ->view('product::public.brand.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
